@@ -27,7 +27,9 @@
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
+#if HAVE_EXECINFO_H
 #include <execinfo.h>
+#endif
 #include <syslog.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
@@ -160,6 +162,7 @@ signal_io_watch (GIOChannel       *ioc,
 static void
 fallback_get_backtrace (void)
 {
+#if HAVE_EXECINFO_H
         void *  frames[64];
         size_t  size;
         char ** strings;
@@ -174,8 +177,11 @@ fallback_get_backtrace (void)
                 free (strings);
                 syslog (LOG_CRIT, "******************* END **********************************");
         } else {
+#endif
                 g_warning ("GDM crashed, but symbols couldn't be retrieved.");
+#if HAVE_EXECINFO_H
         }
+#endif
 }
 
 
